Cadaverous Blooms Worcester, Massachusetts June 1st 2003 13 players Grant Garvin (Evewalker) Deck Name: Beyond the Veil Crypt (12 cards, min=18, max=31, avg=6.17) ------------------------------------------ 3x Howler 8 ANI PRE SPI obf Ahrimane:2 3x Cynthia Ingold 6 SPI ani for pre Ahrimane:2 2x Siamese, The 7 PRE SPI ani pro Ahrimane:2 2x Nettie Hale 5 ani cel pre pro spi Ahrimane:2 2x Juanita Santiago 4 ani pre spi Ahrimane:2 Library (75 cards) Master (11) 2x Animalism 4x Blood Doll 1x Club Zombie 1x KRCG News Radio 1x Pentex(TM) Loves You! 2x Sudden Reversal Action (15) 5x Engling Fury 10x Legal Manipulations Equipment (2) 1x Ivory Bow 1x Mark V Retainer (3) 1x Mr. Winthrop 2x Raven Spy Action Modifier/Combat (8) 8x Swiftness of the Stag Reaction (14) 4x Falcon's Eye 10x Speak with Spirits Combat (22) 6x Aid from Bats 10x Carrion Crows 6x Chameleon's Colors